#from game import Game
#from room import Room
from interactable_requirement import InteractableRequirement

class Interactable:
    def __init__(self, game, room, data : dict):
        self.game                     = game
        self.room                     = room
        self.data         : dict      = data
        self.name         : str       = data["name"]
        self.identifier   : list[str] = data["identifier"]
        self.visible      : bool|str  = data["visible"]
        self.requirements : list[InteractableRequirement] = []

        self.load_requirements()

    def load_requirements(self):
        if "requirements" not in self.data:
            return
        
        for raw_requirement in self.data["requirements"]:
            requirement = InteractableRequirement()
            requirement.interactable = self
            requirement.type = raw_requirement["type"]
            requirement.id = raw_requirement["id"]
            requirement.actions = raw_requirement["actions"]

            self.requirements.append(requirement)
    
    def get_action_requirements(self, action : str) -> list[InteractableRequirement]:
        matching_requirements : list[InteractableRequirement] = []
        
        for requirement in self.requirements:
            if action in requirement.actions:
                matching_requirements.append(requirement)
        
        return matching_requirements
    
    def check_action_requirements(self, action : str, requirements : list[InteractableRequirement]) -> bool:
        all_met = True
        
        for requirement in requirements:
            if requirement.type != "item":
                print(f"[WARN] Unsupported requirement type {requirement.type} in interactable {requirement.interactable}:{action}")
                continue
            
            if requirement.type == "item":
                if requirement.id not in self.game.inventory.get_items():
                    all_met = False
        
        return all_met
    
    def can_see(self):
        return self.visible == True or self.room.has_flag(self.visible)

    def run(self, action : str):
        if not self.can_see():
            print(f"[{self.room.name}] Du kannst nicht genug sehen, um damit etwas zu tun")
            return
        
        requirements = self.get_action_requirements(action)

        if len(requirements) == 0:
            if "success" in self.data["interactions"][action]:
                print(f"[{self.room.name}] {self.data['interactions'][action]['success']['text']}")

                if "action" in self.data["interactions"][action]["success"] and self.data["interactions"][action]["success"]["action"] != None:
                    self.game.run_action(self.data["interactions"][action]["success"]["action"])
                    pass
            
            elif "failed" in self.data["interactions"][action]:
                print(f"[{self.room.name}] {self.data['interactions'][action]['failed']['text']}")

                if "action" in self.data["interactions"][action]["failed"] and self.data["interactions"][action]["failed"]["action"] != None:
                    self.game.run_action(self.data["interactions"][action]["failed"]["action"])
                    pass
        else:
            all_met = self.check_action_requirements(action, requirements)

            if not all_met:
                print(f"[{self.room.name}] {self.data['interactions'][action]['failed']['text']}")

                if self.data["interactions"][action]["failed"]["action"] is not None:
                    self.game.run_action(self.data["interactions"][action]["failed"]["action"])
            else:
                print(f"[{self.room.name}] {self.data['interactions'][action]['success']['text']}")

                if self.data["interactions"][action]["success"]["action"] is not None:
                    self.game.run_action(self.data["interactions"][action]["success"]["action"])


    def use(self):
        self.run("use")

    def take(self):
        self.run("take")

    def look(self):
        self.run("look")

    def __str__(self) -> str:
        return self.name